<template>
  <div class="mod-config">
    <basic-container>
      <ttable
        :table="table"
        @handleSelectionChange="handleSelectionChange"
        :uploadInfo="uploadInfo"
        :prelang="prelang"
        :options="options"
        :ajaxFun="ajaxFun"
        ref="testPlanTable"
        @tableRowClassName="tableRowClassName"
      >
        <template #toolbar></template>
      </ttable>
      <!-- 弹窗, 新增 / 修改 -->
      <table-form
        v-if="addOrUpdateVisible"
        ref="addOrUpdate"
        @refreshDataList="getData"
      ></table-form>
    </basic-container>
  </div>
</template>
<script>
import { fetchList, delObj } from '@/api/quality/testplan'
import ttable from '@/views/common/ztt-table.vue'
import TableForm from './testplan-form'
import { remote } from '@/api/admin/dict'
export default {
  data() {
    return {
      ajaxFun: fetchList,
      uploadInfo: {
        // 是否展示上传EXCEL以及对应的url
        isShow: false,
        url: ''
      },
      prelang: 'testPlan',
      options: {
        height: 300, // 默认高度-为了表头固定
        stripe: true, // 是否为斑马纹 table
        highlightCurrentRow: false, // 是否要高亮当前行
        border: false, // 是否有纵向边框
        lazy: false, // 是否需要懒加载
        fit: true, // 列的宽度是否自撑开
        multiSelect: true, //
        seqNo: true,
        isRefresh: true, // 是否显示刷新按钮
        isShowHide: true, // 是否显示显影按钮
        isSearch: false, // 高级查询按钮
        defaultOrderBy: { column: 'expireTime', direction: 'asc' }
      },
      table: {
        total: 0,
        currentPage: 1,
        pageSize: 20,
        data: [],
        // 标题
        column: [
          // 计划编号
          {
            minWidth: '140',
            prop: 'testPlanNo',
            label: '计划编号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text',
            render: { fun: this.addOrUpdateHandle }
          },
          // 计划名称
          {
            minWidth: '120',
            prop: 'testPlanName',
            label: '计划名称',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 品类
          {
            minWidth: '120',
            prop: 'category',
            label: '品类',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'select',
            formatter: this.formatMaterialCategoryType,
            optList: () => {
              return this.materialCategoryTypeOptions
            }
          },
          // 开始执行时间
          {
            minWidth: '200',
            prop: 'startExecutionTime',
            label: '开始执行时间',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'datetimerange'
          },
          // 结束执行时间
          {
            minWidth: '200',
            prop: 'endExecutionTime',
            label: '结束执行时间',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'datetimerange'
          },
          // 循环周期
          {
            minWidth: '120',
            prop: 'cyclePeriod',
            label: '循环周期',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 周期单位
          {
            minWidth: '120',
            prop: 'cycleUnit',
            label: '周期单位',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'select',
            formatter: this.formatTestplanCycleUnit,
            optList: () => {
              return this.testplanCycleUnitOptions
            }
          },
          // 距离到期日
          {
            minWidth: '120',
            prop: 'expireTime',
            label: '距离到期日',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 状态
          {
            minWidth: '120',
            prop: 'standardId',
            label: '状态',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 备注
          {
            minWidth: '120',
            prop: 'remark',
            label: '备注',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 创建人
          {
            minWidth: '120',
            prop: 'createUser',
            label: '创建人',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 创建时间
          {
            minWidth: '200',
            prop: 'createTime',
            label: '创建时间',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'datetimerange'
          }
        ],
        toolbar: [
          {
            text: '新增',
            type: 'primary',
            fun: this.addOrUpdateHandle
          }
        ],
        operator: [
          {
            text: '删除',
            type: 'text',
            size: 'small',
            fun: this.deleteHandle
          }
        ],
        operatorConfig: {
          fixed: 'right',
          label: '操作',
          width: 100,
          minWidth: 100
        }
      },
      addOrUpdateVisible: false,
      multipleSelection: [],
      materialCategoryTypeOptions: [],
      testplanCycleUnitOptions: [],
      yellowColors: [
        'one-row',
        'two-row',
        'three-row',
        'four-row',
        'five-row',
        'six-row',
        'seven-row',
        'eight-row',
        'nine-row',
        'ten-row',
        'eleven-row',
        'twelve-row',
        'thirteen-row',
        'fourteen-row',
        'ffteen-row',
        'sixteen-row',
        'seventeen-row',
        'eighteen-row',
        'nineteen-row',
        'twenty-row',
        'twenty-one-row',
        'twenty-two-row',
        'twenty-three-row',
        'twenty-four-row',
        'twenty-five-row',
        'twenty-six-row',
        'twenty-seven-row',
        'twenty-eight-row',
        'twenty-nine-row',
        'thirty-row'
      ]
    }
  },
  components: {
    ttable,
    TableForm
  },
  created() {
    this.getMaterialCategoryTypeOptions()
    this.getTestplanCycleUnitOptions()
  },
  methods: {
    // 获取数据列表
    getData() {
      this.$refs.testPlanTable.getDataList()
    },
    // 新增 / 修改
    addOrUpdateHandle(row) {
      this.$router.push({
        name: 'testplanForm',
        params: { id: row == null ? null : row.id }
      })
    },
    // 删除工作站点
    deleteHandle(row) {
      this.$confirm('是否确认删除检测计划为' + row.testPlanName, '提示', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        closeOnClickModal: false,
        type: 'warning'
      })
        .then(function() {
          return delObj(row.id)
        })
        .then((data) => {
          this.$message.success('删除成功')
          this.getData()
        })
    },
    handleSelectionChange(val) {
      // 将选中记录赋值给multipleSelection
      this.multipleSelection = val
    },
    getMaterialCategoryTypeOptions() {
      remote('material_category_type').then((response) => {
        if (response.data.code === 0) {
          this.materialCategoryTypeOptions = response.data.data
        } else {
          this.materialCategoryTypeOptions = []
        }
      })
    },
    // 品类中文格式化
    formatMaterialCategoryType(row, column, cellValue) {
      this.materialCategoryTypeOptions.forEach((obj) => {
        if (obj.value === cellValue) {
          cellValue = obj.label
        }
      })
      return cellValue
    },
    getTestplanCycleUnitOptions() {
      remote('testplan_cycle_unit').then((response) => {
        if (response.data.code === 0) {
          this.testplanCycleUnitOptions = response.data.data
        } else {
          this.testplanCycleUnitOptions = []
        }
      })
    },
    // 周期单位中文格式化
    formatTestplanCycleUnit(row, column, cellValue) {
      this.testplanCycleUnitOptions.forEach((obj) => {
        if (obj.value === cellValue) {
          cellValue = obj.label
        }
      })
      return cellValue
    },
    // 背景色
    tableRowClassName(row, callback) {
      /* let result = ''
      const cyclePeriod = row.cyclePeriod
      const expireTime = row.expireTime
      const len = this.yellowColors.length
      const step = parseInt(len / cyclePeriod)
      const num = len - step * expireTime
      result = this.yellowColors[num]
      callback(result) */
    }
  }
}
</script>
<style>
.commonTable .one-row {
  background: #fff5c4;
}
.commonTable .two-row {
  background: #fff3b6;
}
.commonTable .three-row {
  background: #fff2b1;
}
.commonTable .four-row {
  background: #fff1a8;
}
.commonTable .five-row {
  background: #fdeea0;
}
.commonTable .six-row {
  background: #ffef9b;
}
.commonTable .seven-row {
  background: #ffee97;
}
.commonTable .eight-row {
  background: #ffed93;
}
.commonTable .nine-row {
  background: #ffec8f;
}
.commonTable .ten-row {
  background: #ffeb8a;
}
.commonTable .eleven-row {
  background: #ffea84;
}
.commonTable .twelve-row {
  background: #ffea82;
}
.commonTable .thirteen-row {
  background: #ffe97a;
}
.commonTable .fourteen-row {
  background: #ffe875;
}
.commonTable .ffteen-row {
  background: #ffe76e;
}
.commonTable .sixteen-row {
  background: #ffe66a;
}
.commonTable .seventeen-row {
  background: #ffe563;
}
.commonTable .eighteen-row {
  background: #ffe45b;
}
.commonTable .nineteen-row {
  background: #ffe252;
}
.commonTable .twenty-row {
  background: #ffe14a;
}
.commonTable .twenty-one-row {
  background: #ffe044;
}
.commonTable .twenty-two-row {
  background: #ffdf3f;
}
.commonTable .twenty-three-row {
  background: #ffde37;
}
.commonTable .twenty-four-row {
  background: #ffdd2e;
}
.commonTable .twenty-five-row {
  background: #ffdb25;
}
.commonTable .twenty-six-row {
  background: #ffda22;
}
.commonTable .twenty-seven-row {
  background: #fbd519;
}
.commonTable .twenty-eight-row {
  background: #f7d011;
}
.commonTable .twenty-nine-row {
  background: #fbd208;
}
.commonTable .thirty-row {
  background: #fdd200;
}
</style>
